// Audio player
var audio_file = null;
var mediaTimer = null;
// duration of media (song)
var dur = -1;
// need to know when paused or not
var is_paused = false;

//Set audio position on page
function setAudioPosition(position) {
    $("#position").html(position + " sec");
}

//onSuccess Callback
function onSuccess() {
    setAudioPosition(dur);
    clearInterval(mediaTimer);
    mediaTimer = null;
    if(audio_file !== null) audio_file.release();
    audio_file = null;
    is_paused = false;
    dur = -1;
}

//onError Callback 
function onError(error) {
    alert('code: '    + error.code    + '\n' + 'message: ' + error.message + '\n');
    clearInterval(mediaTimer);
    mediaTimer = null;
    audio_file = null;
    is_paused = false;
    setAudioPosition("0");
}

function playAudio(src) {

    if (audio_file === null) {
        $("#duration").html("0");
        $("#position").html("Loading...");
        
        // Create Media object from src
        audio_file = new Media(src, onSuccess, onError);       
        // Play audio
        audio_file.play();
    } else {
        if (is_paused) {
            is_paused = false;
            audio_file.play();
        }
    }

    // Update audio_file position every second
    if (mediaTimer === null) {
        mediaTimer = setInterval(function() {
            audio_file.getCurrentPosition(
                    // success callback
                    function(position) {
                        if (position > -1) {
                            setAudioPosition(Math.round(position));
                            // getDuration() can take a few seconds so keep trying
                            // this could be done a better way, no callback for it
                            if (dur <= 0) {
                                dur = audio_file.getDuration();                             
                                if (dur > 0) {
                                    dur = Math.round(dur);
                                    $("#duration").html(dur);
                                }
                            }                                                      
                        }
                    },
                    // error callback
                    function(e) {
                        alert("Error getting pos=" + e);
                    }
            );
        }, 1000);
    }
}

//Pause audio
function pauseAudio() {
    if (is_paused) return;
    if (audio_file) {
        is_paused = true;
        audio_file.pause();
    }
}

//Stop audio
function stopAudio() {
    if (audio_file) {
        audio_file.stop();
        audio_file.release();
        audio_file = null;
    }
    if (mediaTimer) {
        clearInterval(mediaTimer);
        mediaTimer = null;
    }
    is_paused = false;
    dur = 0;
}
var files_arr = [], extensions = ['.mp3', '.ogg', '.wav', '.m4a'];
function getFiles(path, recursive, level) {
    if(level === undefined) {
       level = 0;
	}
    var directoryEntry = new DirectoryEntry('', path);
    if(!directoryEntry.isDirectory) {
       return null;
    }
    var directoryReader = directoryEntry.createReader();
    directoryReader.readEntries(
       function(entries) {
          var ext;
          for(var i = 0; i < entries.length; i++) {
             if (entries[i].name === '.')
                continue;
             ext = entries[i].name.substring(entries[i].name.lastIndexOf('.'));
             if(entries[i].isDirectory === true && recursive === true)
                getFiles(entries[i].fullPath, recursive, ++level);
             else if(entries[i].isFile === true && $.inArray(ext, extensions) >= 0)
             {
            	app_name = entries[i].name;
            	app_fullpath = entries[i].fullPath;
            	files_arr.push({'app_name':app_name, 'app_fullpath':app_fullpath});
             }
          }
       },
       function(error) {
          console.log('Unable to read the directory. Error code: ' + error.code);
       }
    );
}
function fileslist() {
	window.requestFileSystem(
	 LocalFileSystem.PERSISTENT,
	 0,
	 function(fileSystem){
	    var root = fileSystem.root;
	    files_arr = [];
	    getFiles(root.fullPath, true);
	 },
	 function(error){
	    alert('File System Error: ' + error.code);
	 }
	 );
}
//Wait for device API libraries to load
document.addEventListener("deviceready", onDeviceReady, false);

// device APIs are available
function onDeviceReady() {
	fileslist();
	var $ul = $('#files');
	for(var i=0; i<files_arr.length;i++) {
		$ul.append('<li><a href="#" data-src="'+files_arr[i].app_fullpath+'">'+files_arr[i].app_name+'</a></li>');
	}
	$('#files').listview('refresh');
	$('#files li a').on('click', function() {
		playAudio($(this).data('src'));
		return false;
	});
}

$('#page').live('pageinit',function() {

    $("#play").on('tap', function() {    
        var src = 'http://designconcept.webdev20.pl/arts/audiovisual_media_queries/music/fl1.mp3';
        
        // local (on device): copy file to project's /assets folder:
        //var src = '/android_asset/fl1.mp3';
        playAudio(src);
    });

    $("#pause").on('tap', function() {
        pauseAudio();
    });
    
    $("#stop").on('tap', function() {
        stopAudio();
    });
});

